@@ -19,7 +19,7 @@
 #import "ConsumerInterface.h"
 
 // +++++++ start
-#import "Agent.h" // used below to look at a producer
+#import "BPCTAgent.h" // used below to look at a producer
 #import "ProducerInterface.h" // used below to look at a producer
 // +++++++ end
 
@@ -393,7 +393,7 @@
 // +++++++ start
   // looking to an other agent, here a producer agent, in a shuffled list
   // this is a specific solution for this ct-hayek application
-  Agent * aProducer;
+  BPCTAgent * aProducer;
   // its interface
   ProducerInterface * aProducerInterface; 
 
